# pynorare
Python package for the NoRaRe collection

[![Build Status](https://travis-ci.org/concepticon/pynorare.svg?branch=master)](https://travis-ci.org/concepticon/pynorare)
[![codecov](https://codecov.io/gh/concepticon/pynorare/branch/master/graph/badge.svg)](https://codecov.io/gh/concepticon/pynorare)
[![PyPI](https://img.shields.io/pypi/v/pynorare.svg)](https://pypi.org/project/pynorare)

